JsonVisualizerColors class

Color palette for JSON visualizer syntax highlighting.

Constructors

JsonVisualizerColors({Color key = const Color(0xFFA31515), Color string = const Color(0xFF0752A5), Color number = const Color(0xFF0B8658), Color boolean = const Color(0xFF0752A5), Color nullValue = const Color(0xFF0752A5), Color bracket = const Color(0xFF181818), Color icon = const Color(0xFF9A9FA5)})
const

Properties

boolean → Color
final
bracket → Color
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Color
final
key → Color
final
nullValue → Color
final
number → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited